Example using over-sampling class methods — Version 0.11.0.dev0

# Example using over-sampling class methods

Data balancing can be performed by over-sampling such that new samples are generated in the minority class to reach a given balancing ratio.

Sample generator used in SMOTE-like samplers

Sample generator used in SMOTE-like samplers

Effect of the shrinkage factor in random over-sampling

Effect of the shrinkage factor in random over-sampling

Compare over-sampling samplers

Compare over-sampling samplers

previous

Plotting Validation Curves

next

Sample generator used in SMOTE-like samplers